@@ -1,3 +1,4 @@
+import os
 import sys
 import unittest
 
@@ -16,7 +17,8 @@ if unittest2_required:
 else:
     import unittest
 
-LOCAL_SERVER = ('127.0.0.1:8881/wsapi/2.0/verify',)
+LOCAL_SERVER = ('http://127.0.0.1:8881/wsapi/2.0/verify',)
+LOCAL_SERVER_HTTPS = ('https://127.0.0.1:8881/wsapi/2.0/verify',)
 
 
 class TestOTPClass(unittest.TestCase):
@@ -46,22 +48,20 @@ class TestOTPClass(unittest.TestCase):
 class TestYubicoVerifySingle(unittest.TestCase):
     def setUp(self):
         yubico.DEFAULT_TIMEOUT = 2
-        yubico.CA_CERTS_BUNDLE_PATH = None
 
         self.client_no_verify_sig = yubico.Yubico('1234', None,
-                                                  api_urls=LOCAL_SERVER,
-                                                  use_https=False)
+                                                  api_urls=LOCAL_SERVER)
         self.client_verify_sig = yubico.Yubico('1234', 'secret123456',
-                                               api_urls=LOCAL_SERVER,
-                                               use_https=False)
+                                               api_urls=LOCAL_SERVER)
 
     def test_invalid_custom_ca_certs_path(self):
         if hasattr(sys, 'pypy_version_info') or PY3:
             # TODO: Figure out why this breaks PyPy and 3.3
             return
 
-        yubico.CA_CERTS_BUNDLE_PATH = '/does/not/exist.1'
-        client = yubico.Yubico('1234', 'secret123456', api_urls=LOCAL_SERVER)
+        client = yubico.Yubico('1234', 'secret123456',
+                               api_urls=LOCAL_SERVER_HTTPS,
+                               ca_certs_bundle_path=os.path.abspath(__file__))
 
         try:
             client.verify('bad')
@@ -69,8 +69,19 @@ class TestYubicoVerifySingle(unittest.TestCase):
             pass
         else:
             self.fail('SSL exception was not thrown')
-        finally:
-            yubico.CA_CERTS_BUNDLE_PATH = None
+
+    def test_custom_ca_certs_path_invalid_path(self):
+        expected_msg = ('Invalid value provided for ca_certs_bundle_path '
+                        'argument')
+        self.assertRaisesRegexp(ValueError, expected_msg,
+                                yubico.Yubico, '1234', 'secret123456',
+                                ca_certs_bundle_path='/does/not/exist.1')
+
+    def test_custom_ca_certs_path(self):
+        file_path = os.path.abspath(__file__)
+        client = yubico.Yubico('1234', 'secret123456',
+                               ca_certs_bundle_path=file_path)
+        self.assertEqual(client._get_ca_bundle_path(), file_path)
 
     def test_replayed_otp(self):
         self._set_mock_action('REPLAYED_OTP')
@@ -205,7 +216,7 @@ class TestYubicoVerifySingle(unittest.TestCase):
 
         self.client_no_verify_sig.verify = mock_verify
 
-        expected_msg = ('More then 7 seconds has passed between generating '
+        expected_msg = ('More than 7 seconds have passed between generating '
                         'the first and the last OTP')
 
         self.assertRaisesRegexp(Exception, expected_msg,
@@ -282,27 +293,35 @@ class TestYubicoVerifySingle(unittest.TestCase):
 
 
 class TestAPIUrls(unittest.TestCase):
-    def test_default_urls_https(self):
+    def test_default_urls(self):
         client = yubico.Yubico('1234', 'secret123456')
-        https_urls = list(map(lambda url: 'https://' + url,
-                              yubico.DEFAULT_API_URLS))
-        self.assertEqual(client.api_urls, https_urls)
+        expected_urls = list(yubico.DEFAULT_API_URLS)
 
-    def test_default_urls_http(self):
-        client = yubico.Yubico('1234', 'secret123456', use_https=False)
-        http_urls = list(map(lambda url: 'http://' + url,
-                             yubico.DEFAULT_API_URLS))
-        self.assertEqual(client.api_urls, http_urls)
+        for url in expected_urls:
+            self.assertTrue(url.startswith('https://'))
+
+        self.assertEqual(client.api_urls, expected_urls)
 
     def test_custom_urls(self):
         custom_urls = ['https://example.com/wsapi/2.0/verify',
                        'http://example.com/wsapi/2.0/verify',
-                       'example.com/wsapi/2.0/verify']
-        verify_urls = custom_urls[:]
-        verify_urls[2] = 'https://' + verify_urls[2]
+                       'http://example.com/wsapi/2.0/verify']
 
         client = yubico.Yubico('1234', 'secret123456', api_urls=custom_urls)
-        self.assertEqual(client.api_urls, verify_urls)
+        self.assertEqual(client.api_urls, custom_urls)
+
+    def test_custom_urls_invalid_or_missing_scheme(self):
+        invalid_urls = [
+            '127.0.0.1:8000/test',
+            'ftp.example.com/test',
+            'example.com'
+        ]
+
+        for url in invalid_urls:
+            expected_msg = r'URL ".+?" contains an invalid or missing scheme'
+            self.assertRaisesRegexp(ValueError, expected_msg,
+                                    yubico.Yubico, '1234', 'secret123456',
+                                    api_urls=[url])
 
     def test_single_url(self):
         single_url = 'http://www.example.com'
